@@ -1262,26 +1262,28 @@ def list_alarms(speaker, action, args, soco_function, use_local_speaker_list):
             [
                 alarm._alarm_id,  # Replace with .alarm_id with SoCo v0.22
                 alarm.zone.player_name,
+                "|",
                 time,
                 duration,
-                title,
-                alarm.volume,
-                convert_true_false(alarm.enabled),
-                alarm.play_mode,
                 alarm.recurrence,
+                convert_true_false(alarm.enabled),
+                title,
+                alarm.play_mode,
+                alarm.volume,
                 convert_true_false(alarm.include_linked_zones),
             ]
         )
     headers = [
         "Alarm ID",
         "Speaker",
+        "|",
         "Start Time",
         "Duration",
-        "Title",
-        "Volume",
-        "Enabled",
-        "Play Mode",
         "Recurrence",
+        "Enabled",
+        "Title",
+        "Play Mode",
+        "Volume",
         "Include Grouped",
     ]
     print()
@@ -1350,9 +1352,9 @@ def add_alarm(speaker, action, args, soco_function, use_local_speaker_list):
         return False
 
     enabled = alarm_parameters[3].lower()
-    if enabled == "on":
+    if enabled in ["on", "yes"]:
         enabled = True
-    elif enabled == "off":
+    elif enabled in ["off", "no"]:
         enabled = False
     else:
         error_and_exit(
@@ -1400,9 +1402,9 @@ def add_alarm(speaker, action, args, soco_function, use_local_speaker_list):
         return False
 
     include_linked = alarm_parameters[7].lower()
-    if include_linked == "on":
+    if include_linked in ["on", "yes"]:
         include_linked = True
-    elif include_linked == "off":
+    elif include_linked in ["off", "no"]:
         include_linked = False
     else:
         error_and_exit(
@@ -1484,9 +1486,9 @@ def modify_alarm(speaker, action, args, soco_function, use_local_speaker_list):
 
         enabled = alarm_parameters[3].lower()
         if not enabled == "_":
-            if enabled == "on":
+            if enabled in ["on", "yes"]:
                 enabled = True
-            elif enabled == "off":
+            elif enabled in ["off", "no"]:
                 enabled = False
             else:
                 error_and_exit(
@@ -1544,9 +1546,9 @@ def modify_alarm(speaker, action, args, soco_function, use_local_speaker_list):
 
         include_linked = alarm_parameters[7].lower()
         if not include_linked == "_":
-            if include_linked == "on":
+            if include_linked in ["on", "yes"]:
                 include_linked = True
-            elif include_linked == "off":
+            elif include_linked in ["off", "no"]:
                 include_linked = False
             else:
                 error_and_exit(
@@ -1568,6 +1570,32 @@ def modify_alarm(speaker, action, args, soco_function, use_local_speaker_list):
     return True
 
 
+@one_parameter
+def copy_alarm(speaker, action, args, soco_function, use_local_speaker_list):
+    """Copy an alarm to the target speaker."""
+    alarms = soco.alarms.get_alarms(speaker)
+    for alarm in alarms:
+        if args[0] == alarm._alarm_id:
+            break
+    else:
+        error_and_exit("Alarm ID '{}' not found".format(args[0]))
+        return False
+
+    if alarm.zone == speaker:
+        error_and_exit("Cannot copy an alarm to the same speaker")
+        return False
+
+    alarm.zone = speaker
+    alarm._alarm_id = None
+    try:
+        alarm.save()
+    except soco.exceptions.SoCoUPnPException:
+        error_and_exit("Failed to copy alarm")
+        return False
+
+    return True
+
+
 @two_parameters
 def alarms_enabled(speaker, action, args, soco_function, use_local_speaker_list):
 
@@ -2775,4 +2803,5 @@ actions = {
     "alarms_enabled": SonosFunction(alarms_enabled, "", False),
     "modify_alarm": SonosFunction(modify_alarm, "", False),
     "modify_alarms": SonosFunction(modify_alarm, "", False),
+    "copy_alarm":  SonosFunction(copy_alarm, "", False),
 }
